@@ -212,8 +212,8 @@ class Text(object):
 
         for _ in range(tries):
             words = prefix + self.chain.walk(init_state)
-            if max_words != None and len(words) > max_words or len(words) < min_words:
-                continue
+            if (max_words != None and len(words) > max_words) or (min_words != None and len(words) < min_words):
+                continue # pragma: no cover # see https://github.com/nedbat/coveragepy/issues/198
             if test_output and hasattr(self, "rejoined_text"):
                 if self.test_sentence_output(words, mor, mot):
                     return self.word_join(words)
@@ -271,8 +271,8 @@ class Text(object):
             output = self.make_sentence(init_state, **kwargs)
             if output is not None:
                 return output
-
-        return None
+        err_msg = "`make_sentence_with_start` can't find sentence beginning with {0}".format(beginning)
+        raise ParamError(err_msg)
 
     @classmethod
     def from_chain(cls, chain_json, corpus=None, parsed_sentences=None):
